#  tests for pyproj-1.9.5.1-py27he834874_1005 (this is a generated file);
print('===== testing package: pyproj-1.9.5.1-py27he834874_1005 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
import sys
import pyproj
pyproj.test()

from pyproj import Proj
Proj(init='epsg:4269')


# Test pyproj_datadir.
if not os.path.isdir(pyproj.pyproj_datadir):
    sys.exit(1)#  --- run_test.py (end) ---

print('===== pyproj-1.9.5.1-py27he834874_1005 OK =====');
print("import: 'pyproj'")
import pyproj

